pub struct Request {
pub method: String,
pub params: Option<Params>,
pub id: Id,
/* private fields */
}Expand description
JSON-RPC 2.0 Request object
A request object represents a call to a method on the server. It contains a method name, optional parameters, and an identifier that will be used to match the response to this request.
Fields
method: StringName of the method to be invoked
params: Option<Params>Parameters to be used during the invocation of the method
id: IdClient-established identifier for this request
Implementations